diff --git a/OpenSim/Framework/Data.MySQL/MySQLDataStore.cs b/OpenSim/Framework/Data.MySQL/MySQLDataStore.cs
index a75223671c..47b3c43480 100644
--- a/OpenSim/Framework/Data.MySQL/MySQLDataStore.cs
+++ b/OpenSim/Framework/Data.MySQL/MySQLDataStore.cs
@@ -312,7 +312,7 @@ namespace OpenSim.Framework.Data.MySQL
MainLog.Instance.Verbose("DATASTORE", "Restored item {0}, {1}", item.Name, item.ItemID);
}
- prim.AddInventoryItems(inventory);
+ prim.RestoreInventoryItems(inventory);
// XXX A nasty little hack to recover the folder id for the prim (which is currently stored in
// every item). This data should really be stored in the prim table itself.
diff --git a/OpenSim/Framework/Data.SQLite/SQLiteRegionData.cs b/OpenSim/Framework/Data.SQLite/SQLiteRegionData.cs
index ba50dca9b1..0035311e30 100644
--- a/OpenSim/Framework/Data.SQLite/SQLiteRegionData.cs
+++ b/OpenSim/Framework/Data.SQLite/SQLiteRegionData.cs
@@ -356,7 +356,7 @@ namespace OpenSim.Framework.Data.SQLite
MainLog.Instance.Verbose("DATASTORE", "Restored item {0}, {1}", item.Name, item.ItemID);
}
- prim.AddInventoryItems(inventory);
+ prim.RestoreInventoryItems(inventory);
// XXX A nasty little hack to recover the folder id for the prim (which is currently stored in
// every item). This data should really be stored in the prim table itself.
diff --git a/OpenSim/Region/Environment/Scenes/SceneObjectPart.Inventory.cs b/OpenSim/Region/Environment/Scenes/SceneObjectPart.Inventory.cs
index c0297cfb6e..a70097456d 100644
--- a/OpenSim/Region/Environment/Scenes/SceneObjectPart.Inventory.cs
+++ b/OpenSim/Region/Environment/Scenes/SceneObjectPart.Inventory.cs
@@ -216,11 +216,13 @@ namespace OpenSim.Region.Environment.Scenes
}
///
/// Add a whole collection of items to the prim's inventory at once. We assume that the items already
/// have all their fields correctly filled out.
///
///
- public void AddInventoryItems(ICollection items)
+ public void RestoreInventoryItems(ICollection items)
{
lock (m_taskInventory)
{
@@ -216,11 +216,13 @@ namespace OpenSim.Region.Environment.Scenes
}
///
- /// Add a whole collection of items to the prim's inventory at once. We assume that the items already
- /// have all their fields correctly filled out.
+ /// Restore a whole collection of items to the prim's inventory at once.
+ /// We assume that the items already have all their fields correctly filled out.
+ /// The items are not flagged for persistence to the database, since they are being restored
+ /// from persistence rather than being newly added.
///
///